@@ -19,6 +19,10 @@ def check_for_updates() -> Optional[str]:
     """Check PyPI for newer version. Returns latest version if update available, None otherwise."""
     try:
         import httpx
+    except ImportError:
+        return None  # httpx not installed, skip update check
+
+    try:
         current = get_version("watchcode-cli")
         response = httpx.get("https://pypi.org/pypi/watchcode-cli/json", timeout=2.0)
         if response.status_code == 200:
@@ -29,8 +33,8 @@ def check_for_updates() -> Optional[str]:
                 latest_parts = [int(x) for x in latest.split(".")]
                 if latest_parts > current_parts:
                     return latest
-    except Exception:
-        pass  # Don't fail on update check errors
+    except (httpx.RequestError, httpx.HTTPStatusError, KeyError, ValueError, json.JSONDecodeError):
+        pass  # Network or parsing error - don't fail CLI
     return None
 
 
@@ -48,11 +52,11 @@ def install_scripts() -> dict:
     watchcode_dir.mkdir(exist_ok=True)
 
     # Scripts to install
+    # NOTE: response_listener.py removed 2026-01-02 (obsolete - relay-only now)
     scripts = [
         "hook_handler.py",
         "cloudkit_poller.py",
-        "apns_sender.py",
-        "response_listener.py"
+        "apns_sender.py"
     ]
 
     try:
